@@ -24,6 +24,7 @@ _batch: Optional['Batch'] = None
 
 def get_batch(name: str | None = None) -> 'Batch':
     global _batch
+    backend: hb.Backend
     if _batch is None:
         if get_config()['hail'].get('backend', 'batch') == 'local':
             logging.info('Initialising Hail Batch with local backend')
@@ -59,12 +60,13 @@ class Batch(hb.Batch):
         self.job_by_tool = dict()
         self.total_job_num = 0
         self.pool_label = pool_label
-        self._copy_configs_to_remote()
+        if not get_config()['hail'].get('dry_run') and not isinstance(
+            self._backend, hb.LocalBackend
+        ):
+            self._copy_configs_to_remote()
 
     def _copy_configs_to_remote(self):
         """If configs are local files, copy them to remote"""
-        if isinstance(self._backend, hb.LocalBackend):
-            return
         remote_dir = to_path(self._backend.remote_tmpdir) / 'config'
         config_path = remote_dir / (str(uuid.uuid4()) + '.toml')
         with config_path.open('w') as f:
@@ -96,9 +98,8 @@ class Batch(hb.Batch):
         part = attributes.get('part')
         label = attributes.get('label', name)
         tool = attributes.get('tool')
-        reuse = attributes.get('reuse', False)
-        if reuse and not tool:
-            tool = '[reuse]'
+        if not tool and name.endswith('Dataproc cluster'):
+            tool = 'hailctl dataproc'
 
         assert isinstance(stage, str | None)
         assert isinstance(dataset, str | None)
@@ -106,7 +107,6 @@ class Batch(hb.Batch):
         assert isinstance(participant_id, str | None)
         assert isinstance(part, str | None)
         assert isinstance(label, str | None)
-        assert isinstance(reuse, bool)
 
         name = make_job_name(
             name=name,
@@ -114,7 +114,6 @@ class Batch(hb.Batch):
             participant_id=participant_id,
             dataset=dataset,
             part=part,
-            reuse=reuse,
         )
 
         if label not in self.job_by_label:
@@ -190,7 +189,6 @@ def make_job_name(
     participant_id: str | None = None,
     dataset: str | None = None,
     part: str | None = None,
-    reuse: bool = False,
 ) -> str:
     """
     Extend the descriptive job name to reflect job attributes.
@@ -203,6 +201,4 @@ def make_job_name(
         name = f'{dataset}: {name}'
     if part:
         name += f', {part}'
-    if reuse:
-        name += ' [reuse]'
     return name
